<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Style Mag
 * @since 1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function style_mag_body_classes( $classes ) {
	global $post;

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Main site layout
	$site_layout = get_theme_mod( 'site_layout', 'box-layout' );
	$classes[] = esc_attr( 'mainsite--' . $site_layout );

	// Menu hover effect
	$menu_hover = get_theme_mod( 'menu_hover_style', 'menu_hover_1' );
	$classes[] = esc_attr( $menu_hover );
	
	$classes[] = esc_attr( 'header--layout-one' );

	$classes[] = esc_attr( 'widget-title-layout-one' );

	$classes[] = 'no_image_design';

	// Manage sidebar layouts
	if( is_page() ) {
		if( is_front_page() ) {
			$frontpage_sidebar_option = get_theme_mod( 'frontpage_sidebar_option', false );
			$frontpage_sidebar_layout = get_theme_mod( 'frontpage_sidebar_layout', 'right-sidebar' );
			$sidebar_layout = $frontpage_sidebar_option ? $frontpage_sidebar_layout : 'no-sidebar';
		} else {
			$post_sidebar_option = get_theme_mod( 'post_sidebar_option', true );
			$post_sidebar_layout = get_theme_mod( 'post_sidebar_layout', 'right-sidebar' );
			$sidebar_layout = $post_sidebar_option ? $post_sidebar_layout : 'no-sidebar';
		}
		//layout settings
		$layout = get_theme_mod( 'post_layout', 'boxed-content-width' ); // layout value
	} else if( is_home() ) {
		$frontpage_sidebar_option = get_theme_mod( 'frontpage_sidebar_option', false );
		$frontpage_sidebar_layout = get_theme_mod( 'frontpage_sidebar_layout', 'right-sidebar' );
		$sidebar_layout = $frontpage_sidebar_option ? $frontpage_sidebar_layout : 'no-sidebar';

		// posts layout
		$archive_posts_layout = get_theme_mod( 'archive_posts_layout', 'list-layout' );
		$classes[] = esc_html( 'posts--'. $archive_posts_layout );
		
	} else if( is_single() ) {
		$post_sidebar_option = get_theme_mod( 'post_sidebar_option', true );
		$post_sidebar_layout = get_theme_mod( 'post_sidebar_layout', 'right-sidebar' );
		$sidebar_layout = $post_sidebar_option ? $post_sidebar_layout : 'no-sidebar';
		//layout settings
		$layout = get_theme_mod( 'post_layout', 'boxed-content-width' ); // layout value
	} else if ( is_archive() ) {
		// posts layout
		$archive_posts_layout = get_theme_mod( 'archive_posts_layout', 'list-layout' );
		$classes[] = esc_html( 'posts--'. $archive_posts_layout );

		$archive_sidebar_option = get_theme_mod( 'archive_sidebar_option', true );
		$archive_sidebar_layout = get_theme_mod( 'archive_sidebar_layout', 'right-sidebar' );
		$layout = get_theme_mod( 'archive_layout', 'boxed-content-width' ); // layout value
		$sidebar_layout = $archive_sidebar_option ? $archive_sidebar_layout : 'no-sidebar';
	}
	$classes[] = isset( $sidebar_layout ) ? esc_attr( $sidebar_layout ) : 'no-sidebar'; // sidebar class
	$classes[] = isset( $layout ) ? esc_attr( $layout ) : 'boxed-content-width'; // layout class

	return $classes;
}
add_filter( 'body_class', 'style_mag_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function style_mag_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'style_mag_pingback_header' );

/**
 * Enqueue scripts and styles.
 */
function style_mag_scripts() {
	wp_enqueue_style( 'style-mag-font-awesome', get_template_directory_uri() . '/assets/lib/fontawesome/css/all.min.css', array(), '5.15.3', 'all' );
	wp_enqueue_style( 'slick-slider', get_template_directory_uri() . '/assets/lib/slick/slick.css', array(), '1.8.1', 'all' );
	// Theme Main Style
	wp_enqueue_style( 'style_mag_maincss', get_template_directory_uri() . '/assets/style/main.css', array(), STYLE_MAG_VERSION );
	//Theme Block Style
	wp_enqueue_style( 'style_mag_blockcss', get_template_directory_uri() . '/assets/style/blocks/blocks.css', array(), STYLE_MAG_VERSION );

	// enqueue inline style
	ob_start();
		include get_template_directory() . '/inc/inline-styles.php';
	$style_mag_theme_inline_sss = ob_get_clean();
	wp_add_inline_style( 'style_mag_maincss', wp_strip_all_tags($style_mag_theme_inline_sss) );

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'style-mag-fonts', style_mag_fonts_url(), array(), null );

	wp_enqueue_style( 'style-mag-style', get_stylesheet_uri(), array(), STYLE_MAG_VERSION );
	wp_style_add_data( 'style-mag-style', 'rtl', 'replace' );

	wp_enqueue_script( 'slick-slider', get_template_directory_uri() . '/assets/lib/slick/slick.min.js', array('jquery'), '1.8.1', true );
	wp_enqueue_script( 'waypoint', get_template_directory_uri() . '/assets/lib/waypoint/jquery.waypoint.min.js', array('jquery'), '4.0.1', true );
	wp_enqueue_script( 'style-mag-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), STYLE_MAG_VERSION, true );
	// stickey js
	wp_enqueue_script( 'sticky-sidebar-js', get_template_directory_uri() . '/assets/lib/sticky/theia-sticky-sidebar.js', array(), '1.7.0', true );
	// theme js
	wp_enqueue_script( 'style-mag-theme', get_template_directory_uri() . '/assets/js/theme.js', array( 'jquery' ), STYLE_MAG_VERSION, true );
	// localize variables
	wp_localize_script( 'style-mag-theme', 'themeVar', array(
		'footerTxt' => esc_html__( 'WordPress Theme | Style Mag by ', 'style-mag' ),
		'themeUrl'	=> esc_url( wp_get_theme()->get( 'ThemeURI' ) ),
		'author' 	=> esc_html( wp_get_theme()->get( 'Author' ) ),
	));

	$scriptVars = array(
		'scrollToTop'		=> get_theme_mod( 'scroll_to_top_option', true ),
		'stickeyHeader_one' => get_theme_mod( 'sticky_header_option', false )
	);
	wp_localize_script( 'style-mag-navigation', 'screenReaderText', array(
		'expand'   => __( 'expand child menu', 'style-mag' ),
		'collapse' => __( 'collapse child menu', 'style-mag' ),
	));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'style_mag_scripts' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function style_mag_widgets_init() {
	// Header toggle sidebar
	register_sidebar(
		array(
			'name'          => esc_html__( 'Header Toggle Sidebar', 'style-mag' ),
			'id'            => 'sidebar-header-toggle',
			'description'   => esc_html__( 'Add widgets here.', 'style-mag' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</span></h2>',
		)
	);

	// default sidebar
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'style-mag' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'style-mag' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</span></h2>',
		)
	);

	// sidebar Page
	register_sidebar(
		array(
			'name'          => esc_html__( 'Page Sidebar', 'style-mag' ),
			'id'            => 'sidebar-page',
			'description'   => esc_html__( 'Add widgets here.', 'style-mag' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</span></h2>',
		)
	);

	// footer sidebars
	register_sidebars( 3, array(
			'name'          => esc_html__( 'Footer Column %d', 'style-mag' ),
			'id'            => 'footer-column',
			'description'   => esc_html__( 'Add widgets here.', 'style-mag' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</span></h2>',
		)
	);
}
add_action( 'widgets_init', 'style_mag_widgets_init' );

//define constant
define( 'STYLE_MAG_INCLUDES_PATH', get_template_directory() . '/inc/' );

/**
 * Elementor modules file
 */
require STYLE_MAG_INCLUDES_PATH . 'elementor-widgets/elementor.php';

/**
 * Theme Hooks
 */
require STYLE_MAG_INCLUDES_PATH . 'hooks/hooks.php';

/**
 * Theme Admin Page 
 * 
 */
require STYLE_MAG_INCLUDES_PATH . 'admin/class-theme-info.php';

/**
 * Register Google fonts.
 * @return string Google fonts URL for the theme.
 */
if ( ! function_exists( 'style_mag_fonts_url' ) ) :
function style_mag_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'cyrillic,cyrillic-ext';

	if ( 'off' !== esc_html_x( 'on', 'Lora: on or off', 'style-mag' ) ) {
		$fonts[] = 'Lora:ital,wght@0,400;0,500;0,600;0,700;1,400;1,500;1,600;1,700';
	}

	if ( 'off' !== esc_html_x( 'on', 'Open Sans: on or off', 'style-mag' ) ) {
		$fonts[] = 'Open Sans:ital,wght@0,400;0,500;0,600;1,400;1,500;1,600&display=swap';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

if( !function_exists( 'style_mag_get_all_posts_ids' ) ) :
	/**
	 * Get all posts ids
	 * 
	 * @return array
	 */
	function style_mag_get_all_posts_ids() {
		$all_post_ids = get_posts([
			'posts_per_page' => -1,
			'post_status' => 'publish',
			'post_type' => 'post',
			'fields' => 'ids',
		]);
		return apply_filters( 'style_mag_get_all_posts_ids_filter', $all_post_ids );
	}
endif;

if( !function_exists( 'style_mag_get_organized_all_posts_ids' ) ) :
	/**
	 * Get organized all posts ids
	 * 
	 * @return array
	 */
	function style_mag_get_organized_all_posts_ids() {
		$ids = array();
		foreach( style_mag_get_all_posts_ids() as $key => $value ) {
			$ids[$value] = $value;
		}
		return apply_filters( 'style_mag_get_organized_all_posts_ids_filter', $ids );
	}
endif;

if( !function_exists( 'style_mag_get_content_type' ) ) :
	/**
	 * Get content type
	 * @return string
	 */
	function style_mag_get_content_type() {
		$content_type = apply_filters( 'style_mag_post_content_type_filter', 'content' );
		if( is_archive() || is_search() || is_home() ) {
			$archive_content_type = get_theme_mod( 'archive_content_type', 'excerpt' );
			$content_type = ( $archive_content_type ) ? esc_html( $archive_content_type ) : 'excerpt';
		}
		return apply_filters( 'style_mag_post_content_type_filter', $content_type );
	}
endif;

// navigation fallback
if ( ! function_exists( 'style_mag_primary_navigation_fallback' ) ) :

	/**
	 * Fallback for primary navigation.
	 *
	 * @since 1.0.0
	 */
	function style_mag_primary_navigation_fallback() {

		echo '<ul id="menu-main-menu" class="primary-menu">';
		echo '<li class="menu-item"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Home', 'style-mag' ) . '</a></li>';
		$args = array(
			'posts_per_page' => 5,
			'post_type'      => 'page',
			'orderby'        => 'name',
			'order'          => 'ASC',
			);
		$the_query = new WP_Query( $args );
		if ( $the_query->have_posts() ) {
			while ( $the_query->have_posts() ) {
				$the_query->the_post();
				the_title( '<li class="menu-item"><a href="' . esc_url( get_permalink() ) . '">', '</a></li>' );
			}
			wp_reset_postdata();
		}
		echo '</ul>';
	}
endif;